pm4py.algo.conformance.footprints package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.footprints.util
   pm4py.algo.conformance.footprints.variants

Submodules
----------

pm4py.algo.conformance.footprints.algorithm module
--------------------------------------------------

.. automodule:: pm4py.algo.conformance.footprints.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.footprints
   :members:
   :undoc-members:
   :show-inheritance:
